.. py:currentmodule:: rubin_sim.moving_objects

.. _rubin_sim.moving_objects:

=======================
rubin_sim MovingObjects
=======================

The movingObjects module provides tools to generate simulated ephemerides of a population of
small bodies throughout an LSST pointing history. These ephemerides are typically used for further
analysis in :doc:`MAF < ../rs_maf/index>` to evaluate the effect of survey strategy on various populations
of Solar System objects.

There are several populations available in the 'orbits' directory of the
rubin_sim data. Many of these populations were contributed or enhanced by the LSST Solar System Science Collaboration (SSSC).
Further documentation on these orbital populations is available in the
`LSST-SSSC "SSSC_test_populations" <https://github.com/lsst-sssc/SSSC_test_populations_gitlfs/tree/master/MAF_TEST>`_ repo.


Python API
==========

* :ref:`rubin_sim.moving_objects api`

* :ref:`search`
